@@ -364,7 +364,7 @@ var sectionTypes = scalar.UintMapSymStr{
 	0x15: "thread_local_init_function_pointers",
 }
 
-func machoDecode(d *decode.D, _ any) any {
+func machoDecode(d *decode.D) any {
 	var archBits int
 	var cpuType uint64
 	var ncmds uint64
