@@ -25,7 +25,7 @@ func init() {
 	})
 }
 
-func frameDecode(d *decode.D, _ any) any {
+func frameDecode(d *decode.D) any {
 	for d.NotEnd() {
 		d.FieldFormat("obu", obuFormat, nil)
 	}
