@@ -5,6 +5,7 @@ package flowsdecoder
 import (
 	"bytes"
 	"encoding/binary"
+	"fmt"
 	"net"
 
 	"github.com/gopacket/gopacket"
@@ -170,6 +171,18 @@ func New(options DecoderOptions) *Decoder {
 	return flowDecoder
 }
 
+func (fd *Decoder) EthernetFrame(bs []byte) error {
+	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeEthernet, gopacket.Lazy))
+}
+
+func (fd *Decoder) IPv4Packet(bs []byte) error {
+	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeIPv4, gopacket.Lazy))
+}
+
+func (fd *Decoder) IPv6Packet(bs []byte) error {
+	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeIPv6, gopacket.Lazy))
+}
+
 func (fd *Decoder) SLLPacket(bs []byte) error {
 	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeLinuxSLL, gopacket.Lazy))
 }
@@ -178,14 +191,22 @@ func (fd *Decoder) SLL2Packet(bs []byte) error {
 	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeLinuxSLL2, gopacket.Lazy))
 }
 
-func (fd *Decoder) EthernetFrame(bs []byte) error {
-	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeEthernet, gopacket.Lazy))
-}
-
 func (fd *Decoder) LoopbackFrame(bs []byte) error {
 	return fd.packet(gopacket.NewPacket(bs, layers.LayerTypeLoopback, gopacket.Lazy))
 }
 
+// LinkTypeRAW IPv4 or Ipv6
+func (fd *Decoder) RAWIPFrame(bs []byte) error {
+	version := bs[0] >> 4
+	switch version {
+	case 4:
+		return fd.IPv4Packet(bs)
+	case 6:
+		return fd.IPv6Packet(bs)
+	}
+	return fmt.Errorf("invalid ip version %v", version)
+}
+
 func (fd *Decoder) packet(p gopacket.Packet) error {
 	// TODO: linkType
 	ip4Layer := p.Layer(layers.LayerTypeIPv4)
@@ -215,6 +236,9 @@ func (fd *Decoder) packet(p gopacket.Packet) error {
 					Datagram:      sb.Bytes(),
 				})
 
+				// i think this replaces p with the newly defragmented ip packet and is
+				// used below when reassembling tcp streams
+				// see gopacket reassemblydump example
 				pb, ok := p.(gopacket.PacketBuilder)
 				if !ok {
 					panic("not a PacketBuilder")
