@@ -12,8 +12,8 @@ func init() {
 	interp.RegisterFormat(decode.Format{
 		Name:        format.AVC_ANNEXB,
 		Description: "H.264/AVC Annex B",
-		DecodeFn: func(d *decode.D, in any) any {
-			return annexBDecode(d, in, annexBAVCNALUFormat)
+		DecodeFn: func(d *decode.D) any {
+			return annexBDecode(d, annexBAVCNALUFormat)
 		},
 		RootArray: true,
 		RootName:  "stream",
