@@ -154,7 +154,7 @@ func decodeMsgPackValue(d *decode.D) {
 	}
 }
 
-func decodeMsgPack(d *decode.D, _ any) any {
+func decodeMsgPack(d *decode.D) any {
 	decodeMsgPackValue(d)
 	return nil
 }
