@@ -18,7 +18,7 @@ func init() {
 	})
 }
 
-func vp9CFMDecode(d *decode.D, _ any) any {
+func vp9CFMDecode(d *decode.D) any {
 	for d.NotEnd() {
 		d.FieldStruct("feature", func(d *decode.D) {
 			id := d.FieldU8("id", vp9FeatureIDNames)
