@@ -12,9 +12,8 @@ type Format struct {
 	ProbeOrder         int // probe order is from low to hi value then by name
 	Description        string
 	Groups             []string
-	DecodeFn           func(d *D, _ any) any
-	DecodeInArg        any
-	DecodeOutType      any
+	DecodeFn           func(d *D) any
+	DefaultInArg       any
 	RootArray          bool
 	RootName           string
 	Dependencies       []Dependency
@@ -44,7 +43,7 @@ type FormatHelp struct {
 	References []HelpReference
 }
 
-func FormatFn(d func(d *D, _ any) any) Group {
+func FormatFn(d func(d *D) any) Group {
 	return Group{{
 		DecodeFn: d,
 	}}
